[compare machine learning algos](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/compare_ml.ipynb)

[interpretable_dl](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/interpretability.ipynb)

[hru discretization laos](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/hru_discretization_laos.ipynb)

[hru discretization](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/hru_discretization.ipynb)

[ecoli modeling with transformations](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/ecoli_modeling_with_transformations.ipynb)

[reading input data from different file types](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/input_data_file_types.ipynb)

[Model Explaination using LIME](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/lime_explainations.ipynb)

[Model Explaination using SHAP](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/shap_explainations.ipynb)

[Visualizing model](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/visualize.ipynb)

[customizing loss function](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/customizing_loss_function.ipynb)

[customizing train step](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/customizing_train_step.ipynb)

[customizing training step in functional api](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/customizing_train_step_with_functional_api.ipynb)

[customizing training loop](https://nbviewer.jupyter.org/github/AtrCheema/AI4Water/blob/dev/examples/paper/customizing_training_loop.ipynb)